<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="750px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="题目类型:" prop="questionType">
          <el-select v-model="state.form.questionType" placeholder="请选择题型" style="width: 100%"  @change="changeType">
            <el-option
                v-for="item in state.questionTypeList"
                :key="item.id"
                :label="item.name"
                style="width: 100%"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="归属题库:" prop="bankName">
          <el-select
              clearable
              v-model="state.form.bankName"
              filterable
              remote
              reserve-keyword
              placeholder="请输入题库名称"
              remote-show-suffix
              :remote-method="getBankList"
              style="width: 100%"
              @change="selectValue"
          >
            <el-option
                v-for="item in state.bankList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
<!--          <el-select-->
<!--              v-model="state.form.bankName"-->
<!--              style="width: 100%"-->
<!--              v-loadMoreNew:[reselect]="handleScroll"-->
<!--              :popper-class="reselect.name"-->
<!--              @change="selectValue"-->
<!--              class="item-width"-->
<!--              placeholder="请选择题库"-->
<!--          >-->
<!--            <el-option-->
<!--                v-for="item in state.bankList"-->
<!--                :key="item.id"-->
<!--                :label="item.name"-->
<!--                :value="item.name"-->
<!--            />-->
<!--          </el-select>-->
        </el-form-item>
        <el-form-item label="题目内容:" prop="title">
          <el-input v-model.trim="state.form.title" type="textarea" placeholder="请输入题目内容"></el-input>
        </el-form-item>
        <el-form-item label="选项:" prop="content" v-if="state.form.questionType != 4">
          <div style="display: flex;flex-direction: column;width: 100%">
            <el-button :disabled="state.form.questionType ===3 || state.form.questionType==null " type="primary"  @click="addOption" size="default" style="width: 65px;margin-bottom: 15px">添加</el-button>
            <div v-for="(item,index) in state.optionItem.items" :key="index" style="width: 100%">
              <div style="display: flex;align-items: center">
                <span>{{String.fromCharCode(index + 65)}}</span>
                <el-input  :disabled="state.form.questionType ===3" type="textarea" v-model="state.optionItem.items[index].content" placeholder="请输入选项内容" style="width: 100%;margin-left: 20px;margin-bottom: 10px"></el-input>
                <Delete v-if="state.form.questionType !==3" style="width: 15px; height: 15px; margin-left: 8px;color: #ed5565" @click="delOption(index)" />
              </div>
            </div>
          </div>
        </el-form-item>

        <el-form-item label="正确答案:" prop="answer">
          <el-radio-group v-model="state.form.answer" v-if="state.form.questionType === 1 || state.form.questionType === 3">
            <div v-for="(item,index) in state.optionItem.items">
              <el-radio :label="String.fromCharCode(index + 65)" style="margin-left: 20px">{{String.fromCharCode(index + 65)}}</el-radio>
            </div>
          </el-radio-group>
          <el-checkbox-group v-model="state.checkList" v-if="state.form.questionType === 2" style="display: flex" @change="changeCheck">
            <div v-for="(item,index) in state.optionItem.items">
              <el-checkbox :label="String.fromCharCode(index + 65)" style="margin-left: 20px;">{{String.fromCharCode(index + 65)}}</el-checkbox>
            </div>
          </el-checkbox-group>
          <el-input v-if="state.form.questionType === 4" v-model="state.form.answer" type="textarea" placeholder="请输入正确答案"></el-input>
        </el-form-item>
        <el-form-item label="解析:" >
          <el-input type="textarea" v-model="state.optionItem.analyze" placeholder="请输入题目解析" style="width: 100%;margin-bottom: 10px"></el-input>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {Delete} from "@element-plus/icons-vue";

import {
  getClassification
} from "@/api/onlineEducation/courseClass";
import {addCourse, checkCourseName, editCourse, getCourseById} from "@/api/onlineEducation/courseManage";
import {getToken} from "@/utils/auth";
import {delPic, getBannerById} from "@/api/onlineEducation/banner";
import Cookies from "js-cookie";
import {
  addQuestionBank,
  checkQuestionBankName,
  editQuestionBank,
  getQuestionBank
} from "@/api/onlineEducation/questionBank";
import {addQuestion, editQuestion, getQuestionById} from "@/api/onlineEducation/question";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startUsername = ref('');
const classifyRef = ref(null)
const state = reactive({
  form: {
    id: '',
    title: '',
    questionType: null,
    bankName: '',
    bankId: null,
    answer: ''
  },
  formRules: {

    questionType: [{required: true, trigger: "blur", message: '请选择题目类型'}],
    bankName: [{required: true, trigger: "blur", message: '请选择归属题库'}],
    title: [{required: true, trigger: "blur", message: '请输入题目内容'}],
    answer: [{required: true, trigger: "blur", message: '请选择正确答案'}],
  },
  classifyList: [],
  isAdmin: false,
  props: {
    checkStrictly: true,
  },
  questionTypeList: [
    {
      id: 1,
      name: '单选题'
    },
    {
      id: 2,
      name: '多选题'
    },
    {
      id: 3,
      name: '判断题'
    },
    {
      id: 4,
      name: '简答题'
    }
  ],
  optionItem: {
    analyze: '',
    items: []
  },
  checkList: [],
  bankList: [],
  bankPageNum: 1, // 当前页码
  bankPageSize: 10, // 每页显示的数量
  hasMoreItems: null, // 是否还有更多选项

})
const reselect = reactive({
  name: 'bank1'
})
const selectValue = (val) => {
  state.bankList.forEach(item => {
    if(item.name === val){
      state.form.bankId = item.id
    }
  })
}
const changeCheck = (val) => {
  console.log('val',val)
  state.form.answer = val.join(',')
}

const addOption = () => {

  const obj = {
    prefix:"",
    content: ''
  }
  state.optionItem.items.push(obj)

}
const delOption = (val) => {
  state.optionItem.items.splice(val,1)
  state.form.answer = ''
  console.log(" state.optionItem.items.", state.optionItem.items)
}
const openDialog = async (type, value) => {
  await getBankList('');
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  if(userInfo.userType === 0){
    state.isAdmin = true;
    state.form.companyName = ''
    state.form.companyId = null
  }else {
    state.isAdmin = false;
    state.form.companyName = userInfo.companyName
    state.form.companyId = userInfo.companyId
  }
  title.value = type === 'addFirst' || type === 'add' ? '新增' : type ==='edit' ? '编辑' : '' ;
  if(type === 'edit') {
    const res = await getQuestionById(value.id)
    if(res.code === 200){
      state.form = res.data
      state.optionItem = JSON.parse(res.data.content)
      if(res.data.questionType === 2){
        state.checkList = res.data.answer.split(',')
      }
    }else{
      ElMessage.warning(res.message)
    }
  }
  dialogVisible.value = true;
}

const getBankList = async (val)=>{
  if(val != ""){
    const queryParams = {
      name: val
    }
    const res = await getQuestionBank(queryParams)
    if (res.code == 200) {
      state.bankList = res.data.list

    } else {
      ElMessage.warning(res.message)
    }
  }else {
    const queryParams = {
      pageNum: 1,
      pageSize: 10
    }
    const res = await getQuestionBank(queryParams)
    if (res.code == 200) {
      state.bankList = res.data.list
    } else {
      ElMessage.warning(res.message)
    }
  }
}

const handleScroll = () => {
  if(state.bankPageNum >= state.hasMoreItems) return
  state.bankPageNum++;
  loadMoreBankData()

}
const loadMoreBankData = async () => {
  const queryParams = {
    pageNum: state.bankPageNum,
    pageSize: state.bankPageSize,
  }
  const res = await getQuestionBank(queryParams)
  if (res.code == 200) {
    state.hasMoreItems = res.data.totalPage
    const data = res.data
    state.bankList = state.bankList.concat(data.list)
  }else{
    ElMessage.warning(res.message)
  }
}


const onSubmit = async () => {
  console.log(" state.form", state.form)
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      const {id,bankName, ...data} = JSON.parse(JSON.stringify(state.form))
      data.answer = data.questionType === 1 || data.questionType === 3 || data.questionType === 4? data.answer : state.checkList.join(',')
      if(data.questionType !== 4){
        const options = state.optionItem.items.map((op,index) => {
          return {
            prefix: String.fromCharCode(index + 65),
            content: op.content,
          }
        })
        data.content = JSON.stringify(
            {
              analyze: state.optionItem.analyze,
              items: options
            }
        )
      }else {
        data.content = JSON.stringify(
            {
              analyze: state.optionItem.analyze,
            })
      }
      console.log('state.form',data)
      const res = await addQuestion(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {bankName,...data} = JSON.parse(JSON.stringify(state.form))
      data.answer = data.questionType === 1 || data.questionType === 3 || data.questionType === 4 ? data.answer : state.checkList.join(',')
      if(data.questionType !== 4){
        const options = state.optionItem.items.map((op,index) => {
          return {
            prefix: String.fromCharCode(index + 65),
            content: op.content,
          }
        })
        data.content = JSON.stringify(
            {
              analyze: state.optionItem.analyze,
              items: options
            }
        )
      }else {
        data.content = JSON.stringify(
            {
              analyze: state.optionItem.analyze,
            })
      }
      const res = await editQuestion(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}
const changeType = () => {
  state.optionItem = {
    analyze: '',
    items: []
  }
  if(state.form.questionType === 3) {
    state.optionItem.items = [
      {
        prefix: 'A',
        content: '是'

      },
      {
        prefix: 'B',
        content: '否'
      }
    ]
  }


}
const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    title: '',
    questionType: null,
    bankName: '',
    bankId: null,
    answer: ''
  }
  state.optionItem = {
    analyze: '',
    items: []
  }
  state.bankPageNum = 1;
  state.bankPageSize = 10;
  state.bankList = []
  state.checkList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
